%global pkg wireguard

%global kernel_version_min 4.18.0-315.el8

# To pick a specific kernel use `--define "kernel_version 4.18.0-315.el8"`
# Otherwise the latest installed kernel-devel version later than
# %%{kernel_version_min} will be used.

%global kernel_version_latest %({ echo %{kernel_version_min}; rpm --query kernel-devel --queryformat '%%{VERSION}-%%{RELEASE}\\\n' | grep -v "package kernel-devel is not installed"; } | sort -V | sed -e '0,/^%{kernel_version_min}$/d' | tail -n 1)

%if "%{kernel_version_latest}" != ""
%{!?kernel_version:%{expand:%%global kernel_version %{kernel_version_latest}}}
%endif

%global _use_internal_dependency_generator 0

%global debug_package %{nil}

%global __spec_install_post \
  %{?__debug_package:%{__debug_install_post}} \
  %{__arch_install_post} \
  %{__os_install_post} \
  %{__mod_compress_install_post}

%global __mod_compress_install_post find %{buildroot}/lib/modules -type f -name \*.ko -exec xz \{\} \\;


Name:             kmod-%{pkg}
Version:          1.0.20210606
Release:          2%{?dist}
Summary:          Fast, modern, secure VPN tunnel

License:          GPLv2
URL:              https://www.wireguard.com/

Source0:          https://git.zx2c4.com/%{pkg}-linux-compat/snapshot/%{pkg}-linux-compat-%{version}.tar.xz

Patch1:           0001-compat-account-for-latest-c8s-backports.patch

ExclusiveArch:    x86_64 aarch64

BuildRequires:    elfutils-libelf-devel
BuildRequires:    gcc
BuildRequires:    kernel-abi-whitelists
BuildRequires:    kernel-rpm-macros
BuildRequires:    kmod
BuildRequires:    make
BuildRequires:    redhat-rpm-config
BuildRequires:    xz

%{!?kernel_version:
BuildRequires:    kernel-devel >= %{kernel_version_min}
}

%{?kernel_version:
BuildRequires:    kernel-devel = %{kernel_version}

Supplements:      kernel = %{kernel_version}

Requires:         (kernel = %{kernel_version} if kernel)

Provides:         kernel-modules = %{kernel_version}.%{_arch}
}

Requires(post):   /usr/sbin/depmod
Requires(postun): /usr/sbin/depmod

Provides:         %{name} = %{?epoch:%{epoch}:}%{version}-%{release}

Supplements:      wireguard-tools
Recommends:       wireguard-tools


%description
WireGuard is an extremely simple yet fast and modern VPN that utilizes
state-of-the-art cryptography. It aims to be faster, simpler, leaner, and more
useful than IPsec, while avoiding the massive headache. It intends to be
considerably more performant than OpenVPN. WireGuard is designed as a general
purpose VPN for running on embedded interfaces and super computers alike, fit
for many different circumstances.


%prep
%autosetup -p1 -n %{pkg}-linux-compat-%{version}


%build
pushd src
%{__make} -C /usr/src/kernels/%{kernel_version}.%{_arch} %{?_smp_mflags} M=$PWD modules
popd


%install
%{__install} -D -t %{buildroot}/lib/modules/%{kernel_version}.%{_arch}/extra/drivers/net/%{pkg} src/%{pkg}.ko

# Make .ko objects temporarily executable for automatic stripping
find %{buildroot}/lib/modules -type f -name \*.ko -exec chmod u+x \{\} \+


%clean
%{__rm} -rf %{buildroot}


%post
/usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}


%postun
/usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}


%files
%defattr(644,root,root,755)
/lib/modules/%{kernel_version}.%{_arch}
%license COPYING
%doc README.md


%changelog
* Thu Jul 29 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 1.0.20210606-2
- Rebuild for 4.18.0-326.el8

* Wed Jul 21 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 1.0.20210606-1
- Initial version
